package com.emsi.tp1biir72.model;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import androidx.annotation.Nullable;

import java.util.ArrayList;

public class MyDB extends SQLiteOpenHelper {
    private static final String DB_NAME = "etablissements.db";
    private static final int DB_VERSION = 1;
    private static final String TABLE_ETAB = "etablissements";
    private static final String ETAB_ID = "id";
    private static final String ETAB_NOM = "nom";
    private static final String ETAB_ADR = "adresse";
    private static final String ETAB_TYP = "type";

    private static MyDB instance;
    public static MyDB getInstance(Context context) {
        if (instance == null)
            instance = new MyDB(context);
        return instance;
    }

    private MyDB(@Nullable Context context) {
        super(context, DB_NAME, null, DB_VERSION);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        db.execSQL("CREATE TABLE " + TABLE_ETAB + " ("
                + ETAB_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, "
                + ETAB_NOM + " TEXT, "
                + ETAB_ADR + " TEXT, "
                + ETAB_TYP + " TEXT)");
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int i, int i1) {
        /// TODO: requêtes pour passer de la version i à la version i1
    }

    public long insertEtab(Etab etab) {
        ContentValues row = new ContentValues();
        row.put(ETAB_NOM, etab.getNom());
        row.put(ETAB_ADR, etab.getAdresse());
        row.put(ETAB_TYP, etab.getType());
        return getWritableDatabase().insert(TABLE_ETAB, null, row);
    }

    public int deleteEtab(long id) {
        return getWritableDatabase().delete(TABLE_ETAB,ETAB_ID+"=?",
                new String[]{String.valueOf(id)});
    }

    public ArrayList<Etab> getEtablissements() {
        ArrayList<Etab> etablissements = new ArrayList<>();
        Cursor c = getReadableDatabase().query(TABLE_ETAB,new String[]{ETAB_ID,ETAB_NOM,ETAB_ADR,ETAB_TYP},
                null,null,null,null,
                ETAB_NOM);
        if(c.moveToFirst())
            do{
                etablissements.add(new Etab(c.getInt(c.getColumnIndexOrThrow(ETAB_ID)),
                                    c.getString(c.getColumnIndexOrThrow(ETAB_NOM)),
                                    c.getString(c.getColumnIndexOrThrow(ETAB_ADR)),
                                    c.getString(c.getColumnIndexOrThrow(ETAB_TYP))));
            }while(c.moveToNext());
        return etablissements;
    }
}
