package com.emsi.tp1biir72.view;

import static android.Manifest.permission.ACCESS_COARSE_LOCATION;
import static android.Manifest.permission.ACCESS_FINE_LOCATION;
import static android.location.LocationManager.GPS_PROVIDER;
import static android.location.LocationManager.NETWORK_PROVIDER;

import android.content.Intent;
import android.content.pm.PackageManager;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.RadioGroup;
import android.widget.TextView;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;

import com.emsi.tp1biir72.controller.EtabAdapter;
import com.emsi.tp1biir72.R;
import com.emsi.tp1biir72.model.Etab;
import com.emsi.tp1biir72.model.MyDB;
import com.emsi.tp1biir72.model.User;

import java.util.ArrayList;
import java.util.List;

public class MainActivity extends AppCompatActivity implements LocationListener {

    private static final int REQUEST_CODE = 101;
    private LocationManager lm;
    ArrayList<Etab> etablissements = new ArrayList<Etab>();
    Location emsi=new Location("");
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_main);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        MyDB db = MyDB.getInstance(this);
        etablissements = db.getEtablissements();
        ListView listView = findViewById(R.id.listEtab);
        EtabAdapter adapter = new EtabAdapter(this, R.layout.my_etab_item, etablissements);
        listView.setAdapter(adapter);
        /*listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                int nb=MyDB.getInstance(MainActivity.this)
                        .deleteEtab(etablissements.get(i).getId());
                if(nb>0) {
                    etablissements.remove(i);
                    adapter.notifyDataSetChanged();
                }
            }
        });*/
        Button afficher = findViewById(R.id.afficher);
        EditText nom = findViewById(R.id.nom);
        EditText adresse = findViewById(R.id.adresse);
        EditText affichage = findViewById(R.id.affichage);
        afficher.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                affichage.setText("Le nom de l'établissement est " + nom.getText() +"\n"
                        + "L'adresse est " + adresse.getText());

                RadioGroup rg=findViewById(R.id.groupe);
                int rbType = rg.getCheckedRadioButtonId();
                String type="";
                if(rbType==R.id.radio1) type="ingenerie";
                else if(rbType==R.id.radio2) type="science_tech";
                else if(rbType==R.id.radio3) type="droit_eco";

                Etab etab= new Etab(nom.getText().toString(),adresse.getText().toString(),
                        type);
                long id=db.insertEtab(etab);
                if(id>0) {
                    etab.setId(id);
                    etablissements.add(etab);
                    adapter.notifyDataSetChanged();
                }
            }
        });
        nom.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {}
            @Override
            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {}
            @Override
            public void afterTextChanged(Editable editable) {
                Toast.makeText(MainActivity.this, "Le nom a changé", Toast.LENGTH_SHORT).show();
            }
        });
        adresse.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {}
            @Override
            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {}
            @Override
            public void afterTextChanged(Editable editable) {
                Toast.makeText(MainActivity.this, "L'adresse a changé", Toast.LENGTH_SHORT).show();
            }
        });
        Intent intent = getIntent();
        User user = (User) intent.getSerializableExtra("user");
        TextView pageTitle = findViewById(R.id.pageTitle);
        pageTitle.setText("Bienvenue " + user.getNom() + " " + user.getPrenom());

        emsi.setLatitude(34.000169);
        emsi.setLongitude(-6.844719);

        //adapter.notifyDataSetChanged();
        lm=(LocationManager) getSystemService(LOCATION_SERVICE);
        if (getApplicationContext().checkSelfPermission(ACCESS_FINE_LOCATION) !=
                PackageManager.PERMISSION_GRANTED &&
                getApplicationContext().checkSelfPermission(ACCESS_COARSE_LOCATION) !=
                        PackageManager.PERMISSION_GRANTED) {
            requestPermissions(new String[]{ACCESS_FINE_LOCATION}, REQUEST_CODE);
            return;
        }
        lm.requestLocationUpdates(GPS_PROVIDER, 1000, 0, this);
        lm.requestLocationUpdates(NETWORK_PROVIDER, 0, 0, this);
    }

    @Override
    protected void onResume() {
        super.onResume();
    }

    @Override
    public void onLocationChanged(@NonNull Location l) {
        Log.d("GPS", l.getProvider()+l.distanceTo(emsi));
        if(l.distanceTo(emsi)>1000){
            Toast.makeText(this, "Vous êtes loin de l'EMSI", Toast.LENGTH_SHORT).show();
        }
    }

    @Override
    public void onLocationChanged(@NonNull List<Location> locations) {
        LocationListener.super.onLocationChanged(locations);
    }

    @Override
    public void onFlushComplete(int requestCode) {
        LocationListener.super.onFlushComplete(requestCode);
    }

    @Override
    public void onProviderEnabled(@NonNull String provider) {
        LocationListener.super.onProviderEnabled(provider);
    }

    @Override
    public void onProviderDisabled(@NonNull String provider) {
        LocationListener.super.onProviderDisabled(provider);
    }

    @Override
    public void onPointerCaptureChanged(boolean hasCapture) {
        super.onPointerCaptureChanged(hasCapture);
    }
}